package com.ruoyi.app.service;

import java.util.List;
import com.ruoyi.app.model.EntranceInspection;

/**
 * 入场检验Service接口
 * 
 * @author coede
 * @date 2025-03-19
 */
public interface IEntranceInspectionService 
{
    /**
     * 查询入场检验
     * 
     * @param id 入场检验主键
     * @return 入场检验
     */
    public EntranceInspection selectEntranceInspectionById(Long id);

    /**
     * 查询入场检验列表
     * 
     * @param entranceInspection 入场检验
     * @return 入场检验集合
     */
    public List<EntranceInspection> selectEntranceInspectionList(EntranceInspection entranceInspection);

    /**
     * 新增入场检验
     * 
     * @param entranceInspection 入场检验
     * @return 结果
     */
    public int insertEntranceInspection(EntranceInspection entranceInspection);

    /**
     * 修改入场检验
     * 
     * @param entranceInspection 入场检验
     * @return 结果
     */
    public int updateEntranceInspection(EntranceInspection entranceInspection);

    /**
     * 批量删除入场检验
     * 
     * @param ids 需要删除的入场检验主键集合
     * @return 结果
     */
    public int deleteEntranceInspectionByIds(Long[] ids);

    /**
     * 删除入场检验信息
     * 
     * @param id 入场检验主键
     * @return 结果
     */
    public int deleteEntranceInspectionById(Long id);
}
